@@ -35,4 +35,10 @@ class DescribeRegionsRequest(RpcRequest):
 		return self.get_query_params().get('ResourceOwnerId')
 
 	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
\ No newline at end of file
+		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+
+	def get_AcceptLanguage(self):
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self,AcceptLanguage):
+		self.add_query_param('AcceptLanguage',AcceptLanguage)
\ No newline at end of file
